(this.webpackJsonpst_mui_dialog=this.webpackJsonpst_mui_dialog||[]).push([[0],{72:function(e,t,a){e.exports=a(82)},82:function(e,t,a){"use strict";a.r(t);var n=a(2),l=a.n(n),o=a(27),i=a.n(o),r=a(7),s=a(34),c=a(36),u=a(124),d=a(121),g=a(128),_=a(126),p=a(127),b=a(115),m=a(125),f=a(61),E=a.n(f),x=a(120),h=["children","onClose","sx"];function y(e){var t=e.children,a=e.onClose,n=e.sx,o=Object(s.a)(e,h);return l.a.createElement(b.a,Object.assign({sx:n},o),t,a?l.a.createElement(m.a,{"aria-label":"close",onClick:a,sx:{position:"absolute",right:8,top:8,color:function(e){return e.palette.grey[500]}}},l.a.createElement(E.a,null)):null)}var O=l.a.forwardRef((function(e,t){return l.a.createElement(x.a,Object.assign({direction:"down",ref:t},e))})),C=Object(c.b)((function(e){var t=l.a.useState(!1),a=Object(r.a)(t,2),o=a[0],i=a[1],s=e.args,b=s.title,m=s.content,f=s.abortlabel,E=s.agreelabel,x=s.height,h=s.fullscreen,C=s.styling_dialog,S=s.button_txt,J=s.button_open_type,v=s.divider,N=s.styling_open_button,j=s.styling_agree_button,k=s.styling_abort_button,w=s.width_dialog,F=s.adapt_width_dialog,H=s.styling_dialog_content,V=s.styling_dialog_title,W=s.styling_dialog_content_text,B=(s.transition_mode,s.slide_direction,s.button_abort_type),I=s.button_agree_type,M=JSON.parse(C),R=JSON.parse(N),T=JSON.parse(j),q=JSON.parse(k),z=JSON.parse(H),A=JSON.parse(V),D=JSON.parse(W),G=function(){i(!1)};return Object(n.useEffect)((function(){o?c.a.setFrameHeight(x):c.a.setFrameHeight()}),[o]),l.a.createElement("div",null,l.a.createElement(u.a,{color:J,variant:"outlined",onClick:function(){i(!0)},sx:R},S),l.a.createElement(d.a,{fullScreen:h,open:o,onClose:G,"aria-labelledby":"alert-dialog-title","aria-describedby":"alert-dialog-description",sx:M,maxWidth:w,fullWidth:F,TransitionComponent:O},l.a.createElement(y,{id:"alert-dialog-title",onClose:G,sx:A},b),l.a.createElement(_.a,{dividers:v,sx:z},l.a.createElement(p.a,{id:"alert-dialog-description",sx:D},m)),l.a.createElement(g.a,null,l.a.createElement(u.a,{onClick:function(){G(),c.a.setComponentValue(!1)},sx:q,color:B},f),l.a.createElement(u.a,{onClick:function(){G(),c.a.setComponentValue(!0)},sx:T,autoFocus:!0,color:I},E))))}));i.a.render(l.a.createElement(l.a.StrictMode,null,l.a.createElement(C,null)),document.getElementById("root"))}},[[72,1,2]]]);
//# sourceMappingURL=main.8bd25ac0.chunk.js.map