self.__precacheManifest = (self.__precacheManifest || []).concat([
  {
    "revision": "e79cdbddab8585c57b69bebd8acd89a3",
    "url": "./index.html"
  },
  {
    "revision": "23416afd1954fc425261",
    "url": "./static/js/2.0fce2338.chunk.js"
  },
  {
    "revision": "2c41efe49968baecc5f58fc671d668d2",
    "url": "./static/js/2.0fce2338.chunk.js.LICENSE.txt"
  },
  {
    "revision": "57778137c98a68d0dfee",
    "url": "./static/js/main.8bd25ac0.chunk.js"
  },
  {
    "revision": "4eae9cfdeaa4b417ff84",
    "url": "./static/js/runtime-main.7050f38a.js"
  }
]);